@@ -15,6 +15,7 @@ sound_event_free (SoundEvent *event)
 	g_free (event->category);
 	g_free (event->name);
 	g_free (event->file);
+	g_free (event->oldfile);
 	g_free (event);
 }
 
@@ -49,6 +50,16 @@ sound_event_set_file (SoundEvent *event, gchar *file)
 	event->modified = TRUE;
 }
 
+void
+sound_event_set_oldfile (SoundEvent *event, gchar *file)
+{
+	g_return_if_fail (event != NULL);
+
+	if (event->oldfile)
+		g_free (event->oldfile);
+	event->oldfile = g_strdup (file);
+}
+
 void
 sound_event_set_desc (SoundEvent *event, gchar *desc)
 {
